```
 ██████╗ ██████╗   ██████╗3 ███╗   ██╗
██╔════╝ ██╔══██╗ ██╔═══██╗ ████╗  ██║
██║      ██████╔╝ ██║   ██║ ██╔██╗ ██║
██║      ██╔══██╗ ██║   ██║ ██║╚██╗██║
╚██████╗ ██║  ██║ ╚██████╔╝ ██║ ╚████║
 ╚═════╝ ╚═╝  ╚═╝  ╚═════╝  ╚═╝  ╚═══╝
```

[![Release](https://github.com/StrayDragon/cro3n/actions/workflows/release.yml/badge.svg)](https://github.com/StrayDragon/cro3n/actions/workflows/release.yml)
[![GitHub last commit](https://img.shields.io/github/last-commit/straydragon/cro3n)](https://github.com/StrayDragon/cro3n/commits)
[![PyPI](https://img.shields.io/pypi/v/cro3n)](https://pypi.org/project/cro3n)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/cro3n)](https://pypi.org/project/cro3n)
[![PyPI - Implementation](https://img.shields.io/pypi/implementation/cro3n)](https://pypi.org/project/cro3n)
[![GitHub](https://img.shields.io/github/license/straydragon/cro3n)](https://github.com/StrayDragon/cro3n/blob/main/LICENSE)

---

Another one **cron expression** utils package for python, wrapped on rust crate [zslayton/cron](https://github.com/zslayton/cron).

## Installation
```bash
pip install -U cro3n
```

## Example
see [example/python](./example/python)

## Related Projects

- [zslayton/cron](https://github.com/zslayton/cron)
- [PyO3/maturin](https://github.com/PyO3/maturin)
- [PyO3/pyo3](https://github.com/PyO3/pyo3)

## LICENSE
[MIT](./LICENSE)